@@ -9,7 +9,7 @@ App::Codit::Plugins::Console - plugin for App::Codit
 use strict;
 use warnings;
 use vars qw( $VERSION );
-$VERSION = 0.02;
+$VERSION = 0.03;
 
 use base qw( Tk::AppWindow::BaseClasses::Plugin );
 
@@ -29,6 +29,11 @@ sub new {
 	return $self;
 }
 
+sub Unload {
+	my $self = shift;
+	return $self->SUPER::Unload
+}
+
 =head1 LICENSE
 
 Same as Perl.
