@@ -9,11 +9,10 @@ App::Codit::Plugins::PodViewer - plugin for App::Codit
 use strict;
 use warnings;
 use vars qw( $VERSION );
-$VERSION = 0.04;
+$VERSION = 0.05;
 
-use base qw( Tk::AppWindow::BaseClasses::Plugin );
+use base qw( App::Codit::BaseClasses::TextModPlugin );
 
-require Tk::NoteBook;
 require Tk::Pod::Text;
 use Tk;
 
@@ -37,47 +36,25 @@ sub new {
 	my $self = $class->SUPER::new(@_, 'ToolBar');
 	return undef unless defined $self;
 
+	$self->{ACTIVEDELAY} = 300;
+	$self->{ADJUSTER} = undef;
 	$self->{DOCS} = {};
 	$self->{MODIFIEDSAVE} = {};
-	$self->{ACTIVEDELAY} = 300;
-	$self->cmdHookAfter('modified', 'activate', $self);
-	$self->cmdHookAfter('doc_close', 'docCloseAfter', $self);
-	$self->cmdHookBefore('doc_close', 'docBefore', $self);
+	$self->{VIEWER} = undef;
+	$self->{VISIBLE} = 0;
 	$self->cmdConfig(
 		flip_pod => ['FlipPod', $self],
 	);
+#	$self->cmdHookBefore('deferred_open', 'selectBlock', $self);
+	$self->PodAdd;
 	return $self;
 }
 
-sub activate {
+
+sub _visible {
 	my $self = shift;
-	my ($name) = @_;
-	$name = $self->extGet('CoditMDI')->docSelected unless defined $name;
-	my $id = $self->{'active_id'};
-	$self->afterCancel($id) if defined $id;
-	return @_ unless (defined $name) and $name;
-	return @_ unless exists $self->{DOCS}->{$name};
-	$self->{'active_id'} = $self->after($self->activeDelay, ['Refresh', $self, $name]);
-	return @_;
-}
-
-sub activeDelay {
-	my $self = shift;
-	$self->{ACTIVEDELAY} = shift if @_;
-	return $self->{ACTIVEDELAY}
-}
-
-
-sub docCloseAfter {
-	my ($self, $result) = @_;
-	my $name = $self->{DOCNAME};
-	$self->{DOCNAME} = undef;
-	return 0 unless $result;
-	if ((defined $name) and $result) {
-		$self->PodRemove($name);
-		delete $self->{DOCS}->{$name}
-	}
-	return $result
+	$self->{VISIBLE} = shift if @_;
+	return $self->{VISIBLE}
 }
 
 sub docBefore {
@@ -89,91 +66,109 @@ sub docBefore {
 	return @_;
 }
 
+#sub docSelect {
+#	my $self = shift;
+#	if (exists $self->{'select_block'}) {
+#		$self->after(100, sub { delete $self->{'select_block'} });
+#		return;
+#	}
+#	$self->SUPER::docSelect;
+#}
+
 sub FlipPod {
 	my $self = shift;
-	my $mdi = $self->extGet('CoditMDI');
-	my $name = $mdi->docSelected;
-	return unless defined $name;
-	my $page = $mdi->Interface->getPage($name);
-	if (exists $self->{DOCS}->{$name}) {
-		$self->PodRemove($name);
+	my $view = $self->{VIEWER};
+	my $adj = $self->{ADJUSTER};
+	if ($self->_visible) {
+		$self->_visible(0);
+		$view->packForget;
+		$adj->packForget;
 	} else {
-		$self->PodAdd($name);
-		$self->Refresh($name);
+		$self->_visible(1);
+		$self->Refresh;
+		$view->pack(-side => 'bottom', -fill => 'both');
+		$adj->pack(-before => $view, -fill => 'x');
 	}
 }
 
 sub PodAdd {
-	my ($self, $name) = @_;
+	my $self = shift;
 	my $mdi = $self->extGet('CoditMDI');
-	my $page = $mdi->Interface->getPage($name);
-	my $title = $self->configGet('-title');
-	my $widg = $mdi->docGet($name)->CWidg;
+	my $page = $self->Subwidget('WORK');
+	my $art = $self->extGet('Art');
+
+	my $podframe = $page->Frame;
 	my $pod;
-	my $podframe = $page->Frame->pack(-fill => 'both');
+
 	my $bframe = $podframe->Frame(
 		-relief => 'groove',
 		-borderwidth => 2,
 	)->pack(-fill => 'x');
-	my $balloon = $self->extGet('Balloon');
-	my $art = $self->extGet('Art');
+
 	my $pr = $bframe->Button(
-		-image => $art->CreateCompound(
+		-image => $art->createCompound(
 			-image => $self->getArt('go-previous', 22),
 			-text => 'Previous'
 		),
 		-relief => 'flat',
 		-command => sub { $pod->history_move(-1) }
 	)->pack(-side => 'left', -padx => 2, -pady => 2);
-	$balloon->Attach($pr, -statusmsg => 'Previous document');
+	$self->StatusAttach($pr, -statusmsg => 'Previous document');
+
 	my $nxt = $bframe->Button(
-		-image => $art->CreateCompound(
+		-image => $art->createCompound(
 			-image => $self->getArt('go-next', 22),
 			-text => 'Next'
 		),
 		-relief => 'flat',
 		-command => sub { $pod->history_move }
 	)->pack(-side => 'left', -padx => 2, -pady => 2);
-	$balloon->Attach($nxt, -statusmsg => 'Next document');
+	$self->StatusAttach($nxt, -statusmsg => 'Next document');
+
 	my $zi = $bframe->Button(
-		-image => $art->CreateCompound(
+		-image => $art->createCompound(
 			-image => $self->getArt('zoom-in', 22),
 			-text => 'Zoom in'
 		),
 		-relief => 'flat',
 		-command => sub { $pod->zoom_in }
 	)->pack(-side => 'left', -padx => 2, -pady => 2);
-	$balloon->Attach($zi, -statusmsg => 'Zoom in');
+	$self->StatusAttach($zi, -statusmsg => 'Zoom in');
+
 	my $zo = $bframe->Button(
-		-image => $art->CreateCompound(
+		-image => $art->createCompound(
 			-image => $self->getArt('zoom-out', 22),
 			-text => 'Zoom out'
 		),
 		-relief => 'flat',
 		-command => sub { $pod->zoom_out }
 	)->pack(-side => 'left', -padx => 2, -pady => 2);
-	$balloon->Attach($zo, -statusmsg => 'Zoom out');
+	$self->StatusAttach($zo, -statusmsg => 'Zoom out');
+
 	my $zr = $bframe->Button(
-		-image => $art->CreateCompound(
+		-image => $art->createCompound(
 			-image => $self->getArt('zoom-original', 22),
 			-text => 'Reset zoom'
 		),
 		-relief => 'flat',
 		-command => sub { $pod->zoom_normal }
 	)->pack(-side => 'left', -padx => 2, -pady => 2);
-	$balloon->Attach($zr, -statusmsg => 'Reset zoom');
+	$self->StatusAttach($zr, -statusmsg => 'Reset zoom');
+
 	$pod = $podframe->PodText(
 		-file => $self->PodFile,
 		-width => 20,
 		-height => 10,
 		-scrollbars => 'oe',
 	)->pack(-expand => 1, -fill => 'both');
-	$self->configPut(-title => $title);
+
 	my $adj = $page->Adjuster(
 		-side => 'bottom',
 		-widget => $podframe,
-	)->pack(-fill => 'x', -before => $podframe);
-	$self->{DOCS}->{$name} = [$pod, $adj, $podframe];
+	);
+	$self->{ADJUSTER} = $adj;
+	$self->{PODWIDGET} = $pod;
+	$self->{VIEWER} = $podframe;
 }
 
 sub PodFile {
@@ -188,37 +183,38 @@ sub PodFile {
 	return $podfile
 }
 
-sub PodList {
-	my $self = shift;
-	my $docs = $self->{DOCS};
-	return keys %$docs
-}
-
 sub PodRemove {
-	my ($self, $name) = @_;
-	my $docs = $self->{DOCS};  
-	my $d = $docs->{$name};
-	return unless defined $d;
-	my ($pod, $adj, $podframe) = @$d;
+	my $self = shift;
+	my $adj = $self->{ADJUSTER};
 	$adj->destroy if (defined $adj) and Exists($adj);
+	my $podframe = $self->{VIEWER};
 	$podframe->destroy if (defined $podframe) and Exists($podframe);
-	delete $docs->{$name};
-	delete $self->{MODIFIEDSAVE}->{$name};
 }
 
 sub Refresh {
-	my ($self, $name) = @_;
-	delete $self->{'active_id'};
-	my $mdi = $self->extGet('CoditMDI');
-	my $widg = $mdi->docGet($name)->CWidg;
+	my $self = shift;
+	$self->SUPER::Refresh;
+
+	return unless $self->_visible;
+
+	my $widg = $self->docWidget;
+	return unless defined $widg;
+
 	my $file = $self->PodFile;
-	my $pod = $self->{DOCS}->{$name}->[0];
 	$widg->saveExport($file);
+
 	my $title = $self->configGet('-title');
+	my $pod = $self->{PODWIDGET};
 	$pod->reload;
 	$self->configPut(-title => $title);
 }
 
+sub selectBlock {
+	my $self = shift;
+	$self->{'select_block'} = 1;
+	return @_;
+}
+
 sub ToolItems {
 	return (
 		[	'tool_separator',],
@@ -233,14 +229,8 @@ sub Quit {
 
 sub Unload {
 	my $self = shift;
-	my @pods = $self->PodList;
-	for (@pods) { $self->PodRemove($_) }
-	unlink $self->PodFile;
-	my $id = $self->{'active_id'};
-	$self->afterCancel($id) if defined $id;
-	$self->cmdUnhookAfter('modified', 'activate', $self);
-	$self->cmdUnhookAfter('doc_close', 'docCloseAfter', $self);
-	$self->cmdUnhookBefore('doc_close', 'docBefore', $self);
+#	$self->cmdUnhookBefore('deferred_open', 'selectBlock', $self);
+	$self->PodRemove;
 	$self->cmdRemove('flip_pod');
 	return $self->SUPER::Unload
 }
